@@ -1,6 +1,8 @@
 import logging
 from abc import abstractmethod
 
+from investing_algorithm_framework.core.models import OrderStatus
+
 logger = logging.getLogger(__name__)
 
 
@@ -14,6 +16,10 @@ class Order:
     def get_order_reference(self):
         pass
 
+    @abstractmethod
+    def set_order_reference(self, order_reference):
+        pass
+
     @abstractmethod
     def get_target_symbol(self):
         pass
@@ -26,6 +32,10 @@ class Order:
     def get_initial_price(self):
         pass
 
+    @abstractmethod
+    def set_initial_price(self, price):
+        pass
+
     @abstractmethod
     def get_price(self):
         pass
@@ -34,12 +44,20 @@ class Order:
     def get_closing_price(self):
         pass
 
+    @abstractmethod
+    def set_closing_price(self, price):
+        pass
+
     @abstractmethod
     def get_side(self):
         pass
 
     @abstractmethod
-    def get_status(self):
+    def get_status(self) -> OrderStatus:
+        pass
+
+    @abstractmethod
+    def set_status(self, status: OrderStatus):
         pass
 
     @abstractmethod
@@ -84,23 +102,6 @@ class Order:
 
         return f"<{self.__class__.__name__} {id(self)}>"
 
-    def repr(self, **fields) -> str:
-        """
-        Helper for __repr__
-        """
-
-        field_strings = []
-        at_least_one_attached_attribute = False
-
-        for key, field in fields.items():
-            field_strings.append(f'{key}={field!r}')
-            at_least_one_attached_attribute = True
-
-        if at_least_one_attached_attribute:
-            return f"<{self.__class__.__name__}({','.join(field_strings)})>"
-
-        return f"<{self.__class__.__name__} {id(self)}>"
-
     def to_string(self):
         return self.repr(
             id=self.get_id(),
